
# kia_hyundai
Connect to your Kia or Hyundai car.

# Usage
```
define my_car fhempy kia_hyundai USERNAME PASSWORD PIN CAR_TYPE REGION_CODE
```

USERNAME: E-Mail address of your Kia/Hyundai account
PASSWORD: Password of your Kia/Hyundai account
PIN: Car PIN
CAR_TYPE: Kia or Hyundai
REGION_CODE: eu, us or ca

Thanks to https://github.com/fuatakgun/kia_uvo which code was used in this module!